@@ -4,7 +4,7 @@ BEGIN {
 	die "Encode::TW not supported on EBCDIC\n";
     }
 }
-our $VERSION = do { my @r = (q$Revision: 0.98 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+our $VERSION = do { my @r = (q$Revision: 1.0 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 use Encode;
 use XSLoader;
@@ -12,6 +12,7 @@ XSLoader::load('Encode::TW',$VERSION);
 
 1;
 __END__
+
 =head1 NAME
 
 Encode::TW - Taiwan-based Chinese Encodings
@@ -29,8 +30,9 @@ Encodings supported are as follows.
 
   Canonical   Alias		Description
   --------------------------------------------------------------------
-  big5        /big-?5$/i	The original Big5 encoding
-  big5-hkscs  /big5-hk(scs)?$/i	Big5 plus Cantonese characters in 
+  big5        /\bbig-?5$/i	The original Big5 encoding
+  big5-hkscs  /\bbig5-hk(scs)?$/i
+                                Big5 plus Cantonese characters in 
                                 Hong Kong
   cp950		                Code Page 950 
                                 (Big5 + Microsoft vendor mappings)
@@ -60,6 +62,6 @@ to find why it is implemented that way.
 
 =head1 SEE ALSO
 
-L<Encode>
+L<Encode>,L<Encode::CJKguide>
 
 =cut
